@@ -1,8 +1,6 @@
 #include <RcppArmadillo.h>
-#include <RcppGSL.h>
-#include <gsl/gsl_sf_hyperg.h>
-#include <gsl/gsl_errno.h>
-#include <gsl/gsl_sf_result.h>
+
+#include "clv_vectorized.h"
 
 
 //' @title GSL Hypergeom 2f0 for equal length vectors
@@ -132,4 +130,12 @@ arma::vec vec_pow(const arma::vec& vA, const arma::vec& vP){
   return(vRes);
 }
 
+arma::vec vec_fill(const double number, const double repetitions){
+  arma::vec vResult(repetitions);
+
+  vResult.fill(number);
+
+  return vResult;
+}
+
 }
