@@ -4,6 +4,7 @@
 
 #include "clv_vectorized.h"
 #include "pnbd_LL_ind.h"
+#include "pnbd_PAlive.h"
 
 //' @name pnbd_PAlive
 //'
@@ -65,8 +66,8 @@ arma::vec pnbd_nocov_PAlive(const double r,
 
   arma::vec vAlpha_i(n), vBeta_i(n);
 
-  vAlpha_i.fill(alpha_0);
-  vBeta_i.fill(beta_0);
+  vAlpha_i = pnbd_nocov_alpha_i(alpha_0, n);
+  vBeta_i = pnbd_nocov_beta_i(beta_0, n);
 
 
   // Calculate PAlive -------------------------------------------------------------
@@ -95,22 +96,12 @@ arma::vec pnbd_staticcov_PAlive(const double r,
                                 const arma::mat& mCov_trans,
                                 const arma::mat& mCov_life){
 
-  if(vCovParams_trans.n_elem != mCov_trans.n_cols)
-    throw std::out_of_range("Vector of transaction parameters need to have same length as number of columns in transaction covariates!");
-
-  if(vCovParams_life.n_elem != mCov_life.n_cols)
-    throw std::out_of_range("Vector of lifetime parameters need to have same length as number of columns in lifetime covariates!");
-
-  if((vX.n_elem != mCov_trans.n_rows) ||
-     (vX.n_elem != mCov_life.n_rows))
-    throw std::out_of_range("There need to be as many covariate rows as customers!");
-
 
   // Build alpha and beta --------------------------------------------
   //  Static covariates: Different alpha/beta for every customer
 
-  const arma::vec vAlpha_i = alpha_0 * arma::exp(((mCov_trans * (-1)) * vCovParams_trans));
-  const arma::vec vBeta_i  = beta_0  * arma::exp(((mCov_life  * (-1)) * vCovParams_life));
+  const arma::vec vAlpha_i = pnbd_staticcov_alpha_i(alpha_0, vCovParams_trans, mCov_trans);
+  const arma::vec vBeta_i  = pnbd_staticcov_beta_i(beta_0, vCovParams_life, mCov_life);
 
   // Calculate PAlive -------------------------------------------------
   return pnbd_PAlive(r,
