@@ -1,6 +1,6 @@
-.fct.helper.s3.fitted.plot <- function(clv.fitted, clv.newdata.nohold, clv.newdata.withhold){
+fct.testthat.runability.clvfittedtransactions.plot <- function(clv.fitted, clv.newdata.nohold, clv.newdata.withhold){
 
-  if(clv.fitted@clv.data@has.holdout){
+  if(clv.data.has.holdout(clv.fitted@clv.data)){
     test_that("Works without prediction end, out-of-the-box", {
       expect_silent(plot(clv.fitted, verbose=FALSE))
     })
@@ -45,7 +45,7 @@
   })
 
 
-  if(clv.fitted@clv.data@has.holdout){
+  if(clv.data.has.holdout(clv.fitted@clv.data)){
     test_that("Warns if ends in holdout", {
       skip_on_cran()
       # prediction.end as character, Date, posix, numeric
@@ -60,7 +60,7 @@
 
   test_that("Works for negative prediction.end", {
     skip_on_cran()
-    if(clv.fitted@clv.data@has.holdout){
+    if(clv.data.has.holdout(clv.fitted@clv.data)){
       # With holdout: Warn about holdout period
       expect_warning(plot(clv.fitted, prediction.end=-2,  verbose=FALSE),
                      regexp = "Not plotting full holdout period.")
@@ -140,3 +140,20 @@
   # })
 
 }
+
+
+
+fct.testthat.runability.clvfittedspending.plot <- function(fitted.spending){
+
+  test_that("Works out-of-the-box", {
+    skip_on_cran()
+    expect_silent(res.plot <- plot(fitted.spending))
+  })
+
+  test_that("Different result for different n", {
+    skip_on_cran()
+    expect_silent(res.plot.10 <- plot(fitted.spending, n = 10, verbose=FALSE))
+    expect_silent(res.plot.20 <- plot(fitted.spending, n = 20, verbose=FALSE))
+    expect_false(isTRUE(all.equal(res.plot.10, res.plot.20)))
+  })
+}
